@@ -3,30 +3,34 @@ use std::str::FromStr;
 use tombi_uri::SchemaUri;
 
 use crate::value::{
-    EmptyFormatRules, TombiValueDirectiveContent, WithCommonLintRules, WithKeyTableLintRules,
+    EmptyFormatRules, TombiValueDirectiveContent, WithCommonFormatRules, WithCommonLintRules,
+    WithKeyFormatRules, WithKeyTableLintRules,
 };
 use crate::TombiCommentDirectiveImpl;
 
 pub type LocalDateFormatRules = EmptyFormatRules;
 
-pub type KeyLocalDateCommonLintRules =
-    WithKeyTableLintRules<WithCommonLintRules<LocalDateLintRules>>;
-
+pub type LocalDateCommonFormatRules = WithCommonFormatRules<LocalDateFormatRules>;
 pub type LocalDateCommonLintRules = WithCommonLintRules<LocalDateLintRules>;
 
-impl TombiCommentDirectiveImpl
-    for TombiValueDirectiveContent<LocalDateFormatRules, KeyLocalDateCommonLintRules>
-{
+pub type KeyLocalDateCommonFormatRules = WithKeyFormatRules<LocalDateCommonFormatRules>;
+pub type KeyLocalDateCommonLintRules = WithKeyTableLintRules<LocalDateCommonLintRules>;
+
+pub type TombiLocalDateDirectiveContent =
+    TombiValueDirectiveContent<LocalDateCommonFormatRules, LocalDateCommonLintRules>;
+
+pub type TombiKeyLocalDateDirectiveContent =
+    TombiValueDirectiveContent<KeyLocalDateCommonFormatRules, KeyLocalDateCommonLintRules>;
+
+impl TombiCommentDirectiveImpl for TombiLocalDateDirectiveContent {
     fn comment_directive_schema_url() -> SchemaUri {
-        SchemaUri::from_str("tombi://json.tombi.dev/tombi-key-local-date-directive.json").unwrap()
+        SchemaUri::from_str("tombi://json.tombi.dev/tombi-local-date-directive.json").unwrap()
     }
 }
 
-impl TombiCommentDirectiveImpl
-    for TombiValueDirectiveContent<LocalDateFormatRules, LocalDateCommonLintRules>
-{
+impl TombiCommentDirectiveImpl for TombiKeyLocalDateDirectiveContent {
     fn comment_directive_schema_url() -> SchemaUri {
-        SchemaUri::from_str("tombi://json.tombi.dev/tombi-local-date-directive.json").unwrap()
+        SchemaUri::from_str("tombi://json.tombi.dev/tombi-key-local-date-directive.json").unwrap()
     }
 }
 
