@@ -1,8 +1,7 @@
-use itertools::Either;
 use tombi_config::TomlVersion;
 use tower_lsp::lsp_types::TextDocumentIdentifier;
 
-use crate::{backend::Backend, config_manager::ConfigSchemaStore};
+use crate::backend::Backend;
 
 #[tracing::instrument(level = "debug", skip_all)]
 pub async fn handle_get_toml_version(
@@ -15,41 +14,17 @@ pub async fn handle_get_toml_version(
     let TextDocumentIdentifier { uri } = params;
     let text_document_uri = uri.into();
 
-    let ConfigSchemaStore {
-        config,
-        schema_store,
-        ..
-    } = backend
-        .config_manager
-        .config_schema_store_for_uri(&text_document_uri)
-        .await;
-
-    let root_ast = backend.get_incomplete_ast(&text_document_uri).await;
-
-    let source_schema = match &root_ast {
-        Some(root) => schema_store
-            .resolve_source_schema_from_ast(root, Some(Either::Left(&text_document_uri)))
-            .await
-            .ok()
-            .flatten(),
-        None => None,
-    };
-
-    let tombi_document_comment_directive = match root_ast.as_ref() {
-        Some(root) => {
-            tombi_validator::comment_directive::get_tombi_document_comment_directive(root).await
+    let (toml_version, source) = {
+        let document_sources = backend.document_sources.read().await;
+        if let Some(document_source) = document_sources.get(&text_document_uri) {
+            backend
+                .text_document_toml_version_and_source(&text_document_uri, document_source.text())
+                .await
+        } else {
+            (TomlVersion::default(), TomlVersionSource::Default)
         }
-        None => None,
     };
 
-    let (toml_version, source) = backend
-        .source_toml_version(
-            tombi_document_comment_directive,
-            source_schema.as_ref(),
-            &config,
-        )
-        .await;
-
     Ok(GetTomlVersionResponse {
         toml_version,
         source,
