@@ -120,7 +120,7 @@ where
                     }
 
                     match value
-                        .validate(&accessors, Some(&current_schema), schema_context)
+                        .validate(accessors, Some(&current_schema), schema_context)
                         .await
                     {
                         Ok(()) => {
