@@ -1,5 +1,7 @@
 use tombi_ast::AstNode;
 
+use crate::semantic_tokens::TokenType;
+
 use super::{AppendSemanticTokens, SemanticTokensBuilder};
 
 impl AppendSemanticTokens for tombi_ast::KeyValue {
@@ -12,6 +14,10 @@ impl AppendSemanticTokens for tombi_ast::KeyValue {
             key.append_semantic_tokens(builder)
         }
 
+        if let Some(token) = self.eq() {
+            builder.add_token(TokenType::OPERATOR, token.into())
+        }
+
         if let Some(value) = self.value() {
             value.append_semantic_tokens(builder)
         }
