@@ -931,7 +931,7 @@ mod completion_labels {
             async fn pyproject_project_description_comment_directive(
                 r#"
                 [project]
-                description = "🦅 TOML Toolkit 🦅 " # tombi: lint█
+                description = "🦅 TOML Toolkit 🦅" # tombi: lint█
                 "#,
                 Schema(pyproject_schema_path()),
             ) -> Ok([
@@ -1220,6 +1220,43 @@ mod completion_labels {
             ]);
         }
 
+        test_completion_labels! {
+            #[tokio::test]
+            async fn cargo_dependencies_local_path_features(
+                r#"
+                [dependencies]
+                local-path-crate = { path = "local-path-crate", features = [█] }
+                "#,
+                Source(project_root_path().join(
+                    "crates/tombi-lsp/tests/fixtures/cargo/path-dependency-with-features/Cargo.toml"
+                )),
+                Schema(cargo_schema_path()),
+            ) -> Ok([
+                "\"default\"",
+                "\"extras\"",
+                "\"flag\"",
+                "\"\"",
+                "''",
+            ]);
+        }
+
+        test_completion_labels! {
+            #[tokio::test]
+            async fn cargo_dependencies_local_path_no_features(
+                r#"
+                [dependencies]
+                local-path-no-features = { path = "local-path-no-features", features = [█] }
+                "#,
+                Source(project_root_path().join(
+                    "crates/tombi-lsp/tests/fixtures/cargo/path-dependency-no-features/Cargo.toml"
+                )),
+                Schema(cargo_schema_path()),
+            ) -> Ok([
+                "\"\"",
+                "''",
+            ]);
+        }
+
         test_completion_labels! {
             #[tokio::test]
             async fn cargo_dependencies_patch(
@@ -1561,6 +1598,7 @@ mod completion_labels {
                     LspService,
                 };
                 use tombi_lsp::handler::handle_did_open;
+                use tombi_text::IntoLsp;
 
                 tombi_test_lib::init_tracing();
 
@@ -1616,6 +1654,8 @@ mod completion_labels {
                             .into(),
                     );
                 };
+                let line_index =
+                tombi_text::LineIndex::new(&toml_text, tombi_text::EncodingKind::Utf16);
 
                 let toml_file_url = match $source_file_path {
                     Some(path) => {
@@ -1650,7 +1690,7 @@ mod completion_labels {
                             },
                             position: (tombi_text::Position::default()
                                 + tombi_text::RelativePosition::of(&toml_text[..index]))
-                            .into(),
+                            .into_lsp(&line_index),
                         },
                         work_done_progress_params: WorkDoneProgressParams::default(),
                         partial_result_params: PartialResultParams {
@@ -1666,7 +1706,7 @@ mod completion_labels {
 
                 let labels = completions
                     .into_iter()
-                    .map(|content| Into::<CompletionItem>::into(content))
+                    .map(|content| IntoLsp::<CompletionItem>::into_lsp(content, &line_index))
                     .sorted_by(|a, b| {
                         a.sort_text
                             .as_ref()
@@ -1812,6 +1852,7 @@ mod completion_labels {
                     LspService,
                 };
                 use tombi_lsp::handler::handle_did_open;
+                use tombi_text::IntoLsp;
 
                 tombi_test_lib::init_tracing();
 
@@ -1893,6 +1934,9 @@ mod completion_labels {
                     );
                 };
 
+                let line_index =
+                tombi_text::LineIndex::new(&toml_text, tombi_text::EncodingKind::Utf16);
+
                 let Ok(toml_file_url) = Url::from_file_path(temp_file.path()) else {
                     return Err("failed to convert temporary file path to URL".into());
                 };
@@ -1919,7 +1963,7 @@ mod completion_labels {
                             },
                             position: (tombi_text::Position::default()
                                 + tombi_text::RelativePosition::of(&toml_text[..index]))
-                            .into(),
+                            .into_lsp(&line_index),
                         },
                         work_done_progress_params: WorkDoneProgressParams::default(),
                         partial_result_params: PartialResultParams {
@@ -1935,7 +1979,7 @@ mod completion_labels {
 
                 let labels = completions
                     .into_iter()
-                    .map(|content| Into::<CompletionItem>::into(content))
+                    .map(|content| IntoLsp::<CompletionItem>::into_lsp(content, &line_index))
                     .sorted_by(|a, b| {
                         a.sort_text
                             .as_ref()
