@@ -450,6 +450,7 @@ mod goto_type_definition_tests {
                     },
                     LspService,
                 };
+                use tombi_text::IntoLsp;
 
                 tombi_test_lib::init_tracing();
 
@@ -499,6 +500,8 @@ mod goto_type_definition_tests {
                 if temp_file.as_file().write_all(toml_text.as_bytes()).is_err() {
                     return Err("failed to write to temporary file".into());
                 };
+                let line_index =
+                tombi_text::LineIndex::new(&toml_text, tombi_text::EncodingKind::Utf16);
 
                 let Ok(toml_file_url) = Url::from_file_path(temp_file.path()) else {
                     return Err("failed to convert temporary file path to URL".into());
@@ -522,7 +525,7 @@ mod goto_type_definition_tests {
                         text_document: TextDocumentIdentifier { uri: toml_file_url },
                         position: (tombi_text::Position::default()
                             + tombi_text::RelativePosition::of(&toml_text[..index]))
-                        .into(),
+                        .into_lsp(&line_index),
                     },
                     work_done_progress_params: WorkDoneProgressParams::default(),
                     partial_result_params: PartialResultParams::default(),
