@@ -2,7 +2,6 @@ mod all_of_schema;
 mod any_of_schema;
 mod array_schema;
 mod boolean_schema;
-mod catalog_uri;
 mod document_schema;
 mod float_schema;
 mod integer_schema;
@@ -12,9 +11,7 @@ mod local_time_schema;
 mod offset_date_time_schema;
 mod one_of_schema;
 mod referable_schema;
-mod schema_accessor;
 mod schema_context;
-mod schema_uri;
 mod source_schema;
 mod string_schema;
 mod table_schema;
@@ -25,9 +22,8 @@ use std::sync::Arc;
 use crate::{Accessor, SchemaStore};
 pub use all_of_schema::AllOfSchema;
 pub use any_of_schema::AnyOfSchema;
-pub use array_schema::ArraySchema;
+pub use array_schema::{ArraySchema, XTombiArrayValuesOrder};
 pub use boolean_schema::BooleanSchema;
-pub use catalog_uri::CatalogUri;
 pub use document_schema::DocumentSchema;
 pub use float_schema::FloatSchema;
 pub use integer_schema::IntegerSchema;
@@ -37,12 +33,12 @@ pub use local_time_schema::LocalTimeSchema;
 pub use offset_date_time_schema::OffsetDateTimeSchema;
 pub use one_of_schema::OneOfSchema;
 pub use referable_schema::{is_online_url, CurrentSchema, Referable};
-pub use schema_accessor::{GetHeaderSchemarAccessors, SchemaAccessor, SchemaAccessors};
 pub use schema_context::SchemaContext;
-pub use schema_uri::SchemaUri;
 pub use source_schema::{SourceSchema, SubSchemaUriMap};
 pub use string_schema::StringSchema;
-pub use table_schema::TableSchema;
+pub use table_schema::{TableKeysOrderGroup, TableSchema, XTombiTableKeysOrder};
+pub use tombi_accessor::{SchemaAccessor, SchemaAccessors};
+pub use tombi_uri::{CatalogUri, SchemaUri};
 pub use value_schema::*;
 
 pub type SchemaProperties =
