@@ -7,11 +7,14 @@ use tombi_extension::CommentContext;
 use tombi_extension::CompletionContent;
 use tombi_extension::CompletionHint;
 use tombi_extension::CompletionKind;
+use tombi_extension::CompletionTextEdit;
+use tombi_extension::TextEdit;
 use tombi_future::Boxable;
 use tombi_schema_store::matches_accessors;
 use tombi_schema_store::Accessor;
 use tombi_schema_store::HttpClient;
 use tombi_version_sort::version_sort;
+use tower_lsp::lsp_types::InsertTextFormat;
 
 use crate::find_path_crate_cargo_toml;
 use crate::find_workspace_cargo_toml;
@@ -254,17 +257,13 @@ async fn complete_crate_version(
                 deprecated: None,
                 edit: match version_value {
                     Some(value) => Some(tombi_extension::CompletionEdit {
-                        text_edit: tower_lsp::lsp_types::CompletionTextEdit::Edit(
-                            tower_lsp::lsp_types::TextEdit {
-                                range: tombi_text::Range::at(position).into(),
-                                new_text: format!("\"{ver}\""),
-                            },
-                        ),
-                        insert_text_format: Some(
-                            tower_lsp::lsp_types::InsertTextFormat::PLAIN_TEXT,
-                        ),
-                        additional_text_edits: Some(vec![tower_lsp::lsp_types::TextEdit {
-                            range: value.range().into(),
+                        text_edit: CompletionTextEdit::Edit(tombi_extension::TextEdit {
+                            range: tombi_text::Range::at(position),
+                            new_text: format!("\"{ver}\""),
+                        }),
+                        insert_text_format: Some(InsertTextFormat::PLAIN_TEXT),
+                        additional_text_edits: Some(vec![TextEdit {
+                            range: value.range(),
                             new_text: "".to_string(),
                         }]),
                     }),
@@ -407,15 +406,13 @@ fn complete_crate_feature<'a: 'b, 'b>(
                 schema_uri: None,
                 deprecated: None,
                 edit: editing_feature_string.map(|value| tombi_extension::CompletionEdit {
-                    text_edit: tower_lsp::lsp_types::CompletionTextEdit::Edit(
-                        tower_lsp::lsp_types::TextEdit {
-                            range: tombi_text::Range::at(position).into(),
-                            new_text: format!("\"{feature}\""),
-                        },
-                    ),
-                    insert_text_format: Some(tower_lsp::lsp_types::InsertTextFormat::PLAIN_TEXT),
-                    additional_text_edits: Some(vec![tower_lsp::lsp_types::TextEdit {
-                        range: value.range().into(),
+                    text_edit: CompletionTextEdit::Edit(TextEdit {
+                        range: tombi_text::Range::at(position),
+                        new_text: format!("\"{feature}\""),
+                    }),
+                    insert_text_format: Some(InsertTextFormat::PLAIN_TEXT),
+                    additional_text_edits: Some(vec![TextEdit {
+                        range: value.range(),
                         new_text: "".to_string(),
                     }]),
                 }),
@@ -493,28 +490,31 @@ async fn fetch_local_crate_features(
     if let Some((_, tombi_document_tree::Value::Table(features_table))) =
         tombi_document_tree::dig_keys(&subcrate_document_tree, &["features"])
     {
-        let mut features = AHashMap::new();
+        let features = features_table
+            .key_values()
+            .iter()
+            .map(|(feature_name, feature_deps)| {
+                let deps = match feature_deps {
+                    tombi_document_tree::Value::Array(arr) => arr
+                        .values()
+                        .iter()
+                        .filter_map(|value| {
+                            if let tombi_document_tree::Value::String(string) = value {
+                                Some(string.value().to_string())
+                            } else {
+                                None
+                            }
+                        })
+                        .collect(),
+                    _ => Vec::new(),
+                };
+                (feature_name.value.clone(), deps)
+            })
+            .collect::<AHashMap<_, _>>();
 
-        for (feature_name, feature_deps) in features_table.key_values() {
-            let feature_name = feature_name.value.clone();
-            let deps = match feature_deps {
-                tombi_document_tree::Value::Array(arr) => arr
-                    .values()
-                    .iter()
-                    .filter_map(|v| {
-                        if let tombi_document_tree::Value::String(s) = v {
-                            Some(s.value().to_string())
-                        } else {
-                            None
-                        }
-                    })
-                    .collect(),
-                _ => Vec::new(),
-            };
-            features.insert(feature_name, deps);
+        if !features.is_empty() {
+            return Some(features);
         }
-
-        return Some(features);
     }
 
     None
