@@ -99,9 +99,7 @@ fn find_path_crate_cargo_toml(
 ) -> Option<(std::path::PathBuf, tombi_document_tree::DocumentTree)> {
     let mut crate_path = crate_path.to_path_buf();
     if !crate_path.is_absolute() {
-        if let Some(workspace_dir) = cargo_toml_path.parent() {
-            crate_path = workspace_dir.join(crate_path);
-        }
+        crate_path = cargo_toml_path.parent()?.join(crate_path);
     }
 
     let Ok(crate_path) = crate_path.canonicalize() else {
@@ -364,6 +362,31 @@ fn goto_crate_package(
     Ok(None)
 }
 
+fn goto_bin_path_target(
+    document_tree: &tombi_document_tree::DocumentTree,
+    accessors: &[tombi_schema_store::Accessor],
+    cargo_toml_path: &std::path::Path,
+) -> Result<Option<tombi_extension::DefinitionLocation>, tower_lsp::jsonrpc::Error> {
+    assert!(matches_accessors!(accessors, ["bin", _, "path"]));
+
+    let Some((_, tombi_document_tree::Value::String(path_value))) =
+        dig_accessors(document_tree, accessors)
+    else {
+        return Ok(None);
+    };
+
+    let Some(uri) =
+        get_uri_relative_to_cargo_toml(std::path::Path::new(path_value.value()), cargo_toml_path)
+    else {
+        return Ok(None);
+    };
+
+    Ok(Some(tombi_extension::DefinitionLocation {
+        uri,
+        range: tombi_text::Range::default(),
+    }))
+}
+
 /// Sanitize the dependency key to be "dependencies" if it is "dev-dependencies" or "build-dependencies".
 ///
 /// This is because the dependency key is always "dependencies" in the workspace Cargo.toml.
@@ -519,6 +542,8 @@ fn goto_definition_for_crate_cargo_toml(
         || matches_accessors!(accessors, ["build-dependencies", _, "path"])
     {
         goto_crate_package(document_tree, accessors, cargo_toml_path, toml_version)
+    } else if matches_accessors!(accessors, ["bin", _, "path"]) {
+        goto_bin_path_target(document_tree, accessors, cargo_toml_path)
     } else {
         Ok(None)
     }?;
@@ -608,3 +633,26 @@ fn get_workspace_path(document_tree: &tombi_document_tree::DocumentTree) -> Opti
         }
     })
 }
+
+fn get_uri_relative_to_cargo_toml(
+    relative_path: &std::path::Path,
+    cargo_toml_path: &std::path::Path,
+) -> Option<tombi_uri::Uri> {
+    let resolved_path = if relative_path.is_absolute() {
+        relative_path.to_path_buf()
+    } else if let Some(cargo_dir) = cargo_toml_path.parent() {
+        cargo_dir.join(relative_path)
+    } else {
+        return None;
+    };
+
+    if !resolved_path.is_file() {
+        return None;
+    }
+
+    let Ok(uri) = tombi_uri::Uri::from_file_path(&resolved_path) else {
+        return None;
+    };
+
+    Some(uri)
+}
