@@ -3,6 +3,8 @@ use tombi_config::{LintOptions, TomlVersion};
 use tombi_diagnostic::{printer::Pretty, Diagnostic, Print};
 use tombi_glob::FileSearch;
 
+use crate::app::CommonArgs;
+
 /// Lint TOML files.
 #[derive(clap::Args, Debug)]
 pub struct Args {
@@ -18,11 +20,14 @@ pub struct Args {
     /// This is useful for determining which JSON Schema should be applied, for more rich linting.
     #[arg(long)]
     stdin_filename: Option<String>,
+
+    #[command(flatten)]
+    common: CommonArgs,
 }
 
 #[tracing::instrument(level = "debug", skip_all)]
-pub fn run(args: Args, offline: bool, no_cache: bool) -> Result<(), crate::Error> {
-    let (success_num, error_num) = match inner_run(args, Pretty, offline, no_cache) {
+pub fn run(args: Args) -> Result<(), crate::Error> {
+    let (success_num, error_num) = match inner_run(args, Pretty) {
         Ok((success_num, error_num)) => (success_num, error_num),
         Err(error) => {
             tracing::error!("{}", error);
@@ -53,12 +58,7 @@ pub fn run(args: Args, offline: bool, no_cache: bool) -> Result<(), crate::Error
     Ok(())
 }
 
-fn inner_run<P>(
-    args: Args,
-    mut printer: P,
-    offline: bool,
-    no_cache: bool,
-) -> Result<(usize, usize), Box<dyn std::error::Error>>
+fn inner_run<P>(args: Args, mut printer: P) -> Result<(usize, usize), Box<dyn std::error::Error>>
 where
     Diagnostic: Print<P>,
     crate::Error: Print<P>,
@@ -71,10 +71,10 @@ where
     let schema_options = config.schema.as_ref();
     let schema_store =
         tombi_schema_store::SchemaStore::new_with_options(tombi_schema_store::Options {
-            offline: offline.then_some(true),
+            offline: args.common.offline.then_some(true),
             strict: schema_options.and_then(|schema_options| schema_options.strict()),
             cache: Some(tombi_cache::Options {
-                no_cache: no_cache.then_some(true),
+                no_cache: args.common.no_cache.then_some(true),
                 ..Default::default()
             }),
         });
